/*
 This file is part of GNU Taler
 (C) 2021-2023 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { createContext } from "preact";
import { useContext } from "preact/hooks";
import { LoginToken } from "../declaration.js";

interface Type {
  id: string;
  token?: LoginToken;
  admin?: boolean;
  changeToken: (t?: LoginToken) => void;
}

const Context = createContext<Type>({} as any);

export const InstanceContextProvider = Context.Provider;
export const useInstanceContext = (): Type => useContext(Context);
